(function($) {
    'use strict';

    moment.locale(oscar_lang);
    var cart_items = typeof selected_accos != 'undefined' ? selected_accos : [];
    var different_date_cart_item;
    var different_date_quantity;

    $('.btn-select-rate').on('click', function() {
        $(this).next().slideToggle('fast', function() {});
    });

    $('.rate-list .rate').on('click', function() {
        if ($(this).hasClass('selected')) {
            return;
        }
        $(this).addClass('selected').siblings().removeClass('selected');
        var price = $(this).data('price');
        var orig_price = $(this).data('orig-price');
        var sorted = $(this).data('sorted');
        var rate_block = $(this).closest('.rate-block');
        var acco_element = $(this).closest('.accommodation-element');
        var range_type = acco_element.data('range');
        var acco_id = parseInt(acco_element.data('id'));
        var arrival = acco_element.data('arrival');
        var departure = acco_element.data('departure');

        acco_element.data('adults', $(this).data('adults'));
        acco_element.data('children', $(this).data('children'));
        acco_element.data('price', price);
        acco_element.data('orig-price', orig_price);
        acco_element.data('sorted', $(this).data('sorted'));
        acco_element.data('promo-amount', $(this).data('promo-amount') || '');

        var acco_selected = accommodations[range_type][
                arrival + '_' + departure
            ][acco_id];
        var conditions_btn = '<div class="conditions modal-button" '
            + 'role=button data-modal=conditions-modal>'
            + '<a><span class="dashicons dashicons-info"></span>'
            + trans_strings.conditions + '</a></div>';
        var selected_rate_has_promo = false;
        var rate_name = '';
        var html = '';

        // Update accommodation's selected rate
        for (var key_price in acco_selected['periods']) {
            if (parseFloat(key_price) == price) {
                var rate_parts = acco_selected['periods'][key_price][sorted];
                if (rate_parts.length == 1) {
                    // Uncombined
                    selected_rate_has_promo = 'orig_price' in rate_parts[0];
                    var rate_id = rate_parts[0].rate_id;
                    var rate = inv_rates[rate_id];
                    if (rate) {
                        rate_name += getOccupancyIcons(rate);
                    }
                    rate_name += ohbeGetName(inv_lang_rates, inv_rates, rate_id);
                    html += '<div class=name>' + rate_name + '</div>'
                        + conditions_btn;
                    acco_element.data('rate', rate_id);
                }
                else {
                    // Combined
                    var rate_ids = '';
                    html += '<div class=name>' + trans_strings.combined_rates
                        + '</div>' + conditions_btn + '<ul class=combined-rates>';
                    for (var i=0; i<rate_parts.length; i++) {
                        var rate_id = rate_parts[i].rate_id;
                        html += '<li>'
                            + ohbeGetName(inv_lang_rates, inv_rates, rate_id)
                            + (rate_parts[i].night_string)
                            + '</li>';
                        if (i > 0) {
                            rate_ids += ',' + rate_id;
                        }
                        else {
                            rate_ids += rate_id;
                        }
                    }
                    acco_element.data('rate', rate_ids);
                    html += '</ul>';
                }
                break;
            }
        }
        html += '<div class=price>'
            + '<div class=ohbe-title>' + trans_strings.per_night + ':</div>';
        if (selected_rate_has_promo) {
            html += '<div class="value orig">'
                + '<span>' + ohbeFormatPrice(orig_price / acco_selected.nights)
                + '</span></div></div>'
                + '<div class=promo>'
                + '<div class="ohbe-title tag">' + acco_selected.promo_code + '</div>'
                + '<div class=value>' + ohbeFormatPrice(price / acco_selected.nights)
                + '</div>';
        }
        else {
            html += '<div class=value>';
            if ($(this).is(':first-child') && !$(this).data('promo-amount')) {
                html += '<div class="tag best-price">'
                    + trans_strings.best_price + '</div>';
            }
            html += ohbeFormatPrice(price / acco_selected.nights) + '</div></div>';
        }
        html += '</div></div>';

        // Change rate with another rate and quantity selected
        for (var key in cart_items) {
            if (
                cart_items[key].acco_id == acco_id
                && cart_items[key].arrival == arrival
                && cart_items[key].departure == departure
            ) {
                cart_items[key].price = acco_element.data('price');
                cart_items[key].orig_price = acco_element.data('orig-price');
                cart_items[key].promo_amount = acco_element.data('promo-amount');
                cart_items[key].rate = acco_element.data('rate');
                cart_items[key].sorted = acco_element.data('sorted');
                cart_items[key].adults = acco_element.data('adults');
                cart_items[key].children = acco_element.data('children');

                updateAccoCardTotalPrice(
                    $(this).closest('.rate-block'),
                    parseInt(acco_element.find('.accos-quantity .value').val()),
                    selected_rate_has_promo
                );
                setCartItemList();
                scrollToCart();
                break;
            }
        }
        rate_block.find('.info').html(html).fadeIn(1000);
        rate_block.find('.quantity-total-block').fadeIn(1000);
        $(this).closest('.rate-list').slideUp('fast', function() {});
    });

    $('.btn-select-quantity.has-list').on('click', function() {
        $(this).siblings('.quantity-list').slideToggle('fast', function() {});
    });

    $('.quantity-list .quantity, .btn-select-quantity.has-no-list').on(
        'click',
        function() {
        // Do nothing if accommodation is already selected
        if ($(this).hasClass('selected')) {
            return;
        }
        $(this).addClass('selected').siblings().removeClass('selected');

        var acco_element = $(this).closest('.accommodation-element');
        var arrival = acco_element.data('arrival');
        var departure = acco_element.data('departure');
        var quantity = parseInt($(this).data('quantity'));
        var acco_id = parseInt(acco_element.data('id'));
        var is_selected = false;

        // Hide lists
        if ($(this).hasClass('quantity'))
            $(this).closest('.quantity-list').slideUp('fast', function() {});
        $(this)
            .closest('.quantity-total-block')
            .siblings('.rate-list')
            .slideUp('fast', function() {});

        // Check if the selected accommodation has another date range
        if (
            Object.keys(cart_items)[0]
            && (cart_items[Object.keys(cart_items)[0]]['arrival'] != arrival
                || cart_items[Object.keys(cart_items)[0]]['departure'] != departure)
        ) {
            different_date_cart_item = acco_element;
            different_date_quantity = quantity;
            ohbeModalOpen($('#ohbe-different-dates'));
            return;
        }
        // Check if item already existed in cart list
        for (var i=0; i<cart_items.length; i++) {
            if (cart_items[i].acco_id == acco_id) {
                if (quantity > 0) {
                    cart_items[i].quantity = quantity;
                }
                else {
                    cart_items.splice(i, 1);
                    $('.accommodation-booked-list').find('[data="' + acco_id + '"]')
                        .parent().remove();
                    acco_element.removeClass('selected');
                }
                is_selected = true;
                break;
            }
        }
        // Add item into cart list
        if (!is_selected) {
            cart_items.push({
                range: acco_element.data('range'),
                quantity: quantity,
                acco_id: acco_id,
                name: ohbeGetName(inv_lang_accos, inv_accos, acco_id),
                arrival: arrival,
                arrival_string: moment(arrival).format('ddd D MMM YYYY'),
                departure: departure,
                departure_string: moment(departure).format('ddd D MMM YYYY'),
                amount: acco_element.data('amount'),
                adults: parseInt(acco_element.data('adults')),
                children: parseInt(acco_element.data('children')),
                price: parseFloat(acco_element.data('price')),
                orig_price: acco_element.data('orig-price')
                    ? parseFloat(acco_element.data('orig-price'))
                    : '',
                promo_amount: acco_element.data('promo-amount')
                    ? parseFloat(acco_element.data('promo-amount'))
                    : '',
                rate: acco_element.data('rate'),
                sorted: parseFloat(acco_element.data('sorted')),
                excl_taxes: acco_element.data('taxes') || 0
            });
            acco_element.addClass('selected');
        }
        updateAccoCardTotalPrice($(this).closest('.rate-block'), quantity);
        setCartItemList();
        if (cart_items.length > 0) {
            scrollToCart();
        }
    });

    $(document).on('click','.delete-acco', function() {
        var acco_selected = $(this).closest('.accommodation-booked');
        for (var i=0; i<cart_items.length; i++) {
            if (cart_items[i].acco_id == parseInt(acco_selected.data('id'))) {
                var acco_element = $('.accommodation-list')
                    .find('.accommodation-element[data-id="'
                    + cart_items[i].acco_id + '"]');
                var block_total_qty = acco_element.find(
                    '.rate-block .quantity-total-block'
                );
                acco_element.removeClass('selected');
                block_total_qty.find('.btn-select-quantity').removeClass('selected');
                block_total_qty.find('.quantity-list .quantity[data-quantity="'
                    + cart_items[i].quantity + '"]').removeClass('selected');
                block_total_qty.find('.total .value').html(ohbeFormatPrice(0));
                block_total_qty.find('.total').hide();
                block_total_qty.find('.total-promo').hide();
                acco_selected.remove();
                cart_items.splice(i, 1);
            }
        }
        setCartItemList();
    });

    $('#ohbe-booking-summary-form').on('submit', function() {
        $('#ohbe-accommodations-input').val(JSON.stringify(cart_items));
    });

    $(document).on('click', '.conditions', function() {
        var acco_element = $(this).closest('.accommodation-element');
        var acco_rates = acco_element.data('rate').toString().split(',');
        var html = '';
        var nl = /(?:\r\n|\r|\n)/g;

        $.each(acco_rates, function (i, rate_id) {
            var lang_rate = inv_lang_rates[rate_id];
            var inventory_rate = inv_rates[rate_id];
            html += '<div class=rate-header>'
                + renderOccupancy('adults', inventory_rate);
            if (inventory_rate['adults'] > 5 || inventory_rate['children'] > 5) {
                html += '<span></span>';
            }
            html += renderOccupancy('children', inventory_rate)
                + '<h4 class=header>'
                + ohbeGetName(inv_lang_rates, inv_rates, rate_id)
                + '</h4></div>';
            if (lang_rate.description) {
                html += '<h4 class=header>' + trans_strings.description + '</h4>'
                    + '<p>' + lang_rate.description
                    .replace(nl, '<br>') + '</p>';
            }
            if (lang_rate.payment) {
                html += '<h4 class=header>' + trans_strings.payment + '</h4>' +
                    '<p>' + lang_rate.payment
                    .replace(nl, '<br>') + '</p>';
            }
            if (lang_rate.cancellation) {
                html += '<h4 class=header>' + trans_strings.cancellation + '</h4>'
                    + '<p>' + lang_rate.cancellation
                    .replace(nl, '<br>') + '</p>';
            }
        });

        // Set a default text when there is no conditions text
        if (html == '' && !inv_lang_checkinout && !inv_lang_conditions) {
            html = trans_strings.noConditions;
        }

        $('#ohbe-conditions-modal .rate-content').html(html);
    });

    $(document).on('click', '.modal-button',function() {
        var data_modal = $(this).data('modal');
        if (data_modal == 'description-modal') {
            var acco_id = $(this).closest('.accommodation-element').data('id');
            var title = $(this).closest('.accommodation-element').data('name');
            var description = (
                inv_lang_accos[acco_id] && inv_lang_accos[acco_id].description
                ) || '';
            var isCarousel = inv_accos[acco_id]['images']
                && inv_accos[acco_id]['images'].length > 1;
            var body = isCarousel
                ? ohbeRenderCarousel(acco_id, $(this).data('active-item'))
                : ohbeRenderImage(acco_id);
            body += '<div class=description>'
                + description.replace(/(?:\r\n|\r|\n)/g, '<br>')
                + '</div>';
            $('#ohbe-description-modal .modal-title').html(title);
            $('#ohbe-description-modal .modal-body').html(body);
            if (isCarousel) {
                var carousel = $("#modal-carousel");
                carousel.carousel({interval: 3000});
                carousel.on('click', '.item.active', function() {
                    carousel.children('.carousel-inner').children()
                        .last().hasClass('active')
                        ? carousel.carousel(0)
                        : carousel.carousel('next');
                });
            }
        }
        ohbeModalOpen($('#ohbe-' + data_modal));
    });

    $('#ohbe-different-dates-yes').on('click', function() {
        var arrival = different_date_cart_item.data('arrival');
        var departure = different_date_cart_item.data('departure');
        var acco_id = parseInt(different_date_cart_item.data('id'));
        var price = parseFloat(different_date_cart_item.data('price'));
        var orig_price = different_date_cart_item.data('orig-price')
            ? parseFloat(different_date_cart_item.data('orig-price'))
            : '';
        var promo_amount = different_date_cart_item.data('promo-amount')
            ? parseFloat(different_date_cart_item.data('promo-amount'))
            : '';
        var name = ohbeGetName(inv_lang_accos, inv_accos, acco_id);

        cart_items = [];
        cart_items.push({
            range: different_date_cart_item.data('range'),
            quantity: different_date_quantity,
            acco_id: acco_id,
            name: name,
            arrival: arrival,
            arrival_string: moment(arrival).format('ddd D MMM YYYY'),
            departure: departure,
            departure_string: moment(departure).format('ddd D MMM YYYY'),
            amount: different_date_cart_item.data('amount'),
            adults: parseInt(different_date_cart_item.data('adults')),
            children: parseInt(different_date_cart_item.data('children')),
            price: price,
            orig_price: orig_price,
            promo_amount: promo_amount,
            rate: different_date_cart_item.data('rate'),
            sorted: parseFloat(different_date_cart_item.data('sorted')),
            excl_taxes: different_date_cart_item.data('taxes') || 0,
            periods: []
        });

        $('.accommodation-element').removeClass('selected');
        var quantity_total_block = $('.quantity-total-block');
        quantity_total_block.find('.accos-quantity .value').val(0);
        quantity_total_block.find('.total .value').text(ohbeFormatPrice(0));
        quantity_total_block.find('.total').hide();
        quantity_total_block.find('.total-promo').hide();
        updateAccoCardTotalPrice(
            different_date_cart_item.find('.rate-block'),
            different_date_quantity
        );
        setCartItemList();
        scrollToCart();

        different_date_cart_item.addClass('selected');
        different_date_cart_item.find('.accos-quantity .value')
            .val(different_date_quantity);
        ohbeModalClose();
        $('.rate-list').slideUp('fast', function() {});
    });

    $('#ohbe-different-dates-no').on('click', function() {
        different_date_cart_item.find('.accos-quantity .value').val(0);
        ohbeModalClose();
    });

    $('.ohbe-accordion').accordion({
        collapsible: true,
        active: false,
        heightStyle: 'content'
    });

    /**
     * Update the total price's accommodation card.
     *
     * @return void
     */
    function updateAccoCardTotalPrice(
        rate_block,
        quantity_val,
        selected_rate_has_promo
    ) {
        var quantity_total_block = rate_block.children('.quantity-total-block');
        var rate_selected = rate_block.find('.rate-list .selected');
        var total_block = quantity_total_block.find('.total');
        var total_promo_block = quantity_total_block.find('.total-promo');
        var price = rate_selected.data('price');
        var orig_price = rate_selected.data('orig-price');
        var promo_amount = rate_selected.data('promo-amount');

        if (promo_amount) {
            total_block.children('.value').removeClass('orig').text(ohbeFormatPrice(
                parseFloat(price) * quantity_val)
            );

            total_promo_block.hide();
        }
        else if (orig_price) {
            total_block.children('.value').addClass('orig').text(ohbeFormatPrice(
                parseFloat(orig_price) * quantity_val)
            );

            total_promo_block.find('.value').text(
                ohbeFormatPrice(parseFloat(price) * quantity_val)
            );
            total_promo_block.show();
        }
        else {
            total_block.children('.value').removeClass('orig').text(
                ohbeFormatPrice(parseFloat(price) * quantity_val)
            );
            total_promo_block.hide();
        }
        if (quantity_val > 0) {
            total_block.show();

            if (selected_rate_has_promo) {
                total_promo_block.show();
            }
        }
        else {
            total_block.hide();
            total_promo_block.hide();
        }
    }

    /**
     * Update carts' items
     *
     * @return void
     */
    function setCartItemList() {
        var total_orig_price = 0;
        var total_promo_amount = 0;
        var html = '';

        for (var i=0; i<cart_items.length; i++) {
            var acco_name_quantity = cart_items[i].quantity > 1
                ? cart_items[i].quantity + ' × ' : '';
            var rate_parts = accommodations[cart_items[i].range]
                [cart_items[i].arrival + '_' + cart_items[i].departure]
                [cart_items[i].acco_id]['periods'][cart_items[i].price]
                [cart_items[i].sorted];
            var periods = [];

            html += '<div class=accommodation-booked '
                + 'data-id="' + cart_items[i].acco_id + '">'
                + ohbeRenderImage(cart_items[i].acco_id, 'acco-image')
                + '<div class=acco-info>'
                + '<h4 class=ohbe-title>'
                + acco_name_quantity + cart_items[i].name
                + '</h4>'
                + '<div class=date>'
                + '<label class=ohbe-title>' + trans_strings.arrival + ': </label>'
                + '<div class=value>' + cart_items[i].arrival_string + '</div>'
                + '</div>'
                + '<div class=date>'
                + '<label class=ohbe-title>' + trans_strings.departure + ': </label>'
                + '<div class=value>' + cart_items[i].departure_string + '</div>'
                + '</div>'
                + '<div class=accommodation-rate>'
                + '<label class=ohbe-title>' + trans_strings.rate + ': </label>'
                + '<div class=value>';
            for (var j=0; j<rate_parts.length; j++) {
                if (j > 0) {
                    html += ', ';
                }
                html += ohbeGetName(
                    inv_lang_rates,
                    inv_rates,
                    rate_parts[j].rate_id
                );
                periods.push({
                    rate_id: rate_parts[j].rate_id,
                    days: rate_parts[j].days
                });
            }
            html += '</div></div>'
                + '<div class=accommodation-rate>'
                + '<label class=ohbe-title>' + trans_strings.maximum + ': </label>'
                + '<div class=value>'
                + getOccupancyIcons(rate_parts[0])
                + '</div></div>'
                + '<div class=accommodation-price>'
                + '<label class=ohbe-title>'
                + getTaxesString(cart_items[i], trans_strings) + ': </label>'
                + '<div class=value>'
                + ohbeFormatPrice(cart_items[i].quantity * cart_items[i].price)
                + '</div></div>'
                + '<div class=clear></div>'
                + '</div>'
                + '<div class=delete>'
                + '<a class=delete-acco role=button>'
                + '<span class="dashicons dashicons-no"></span></a>'
                + '</div></div>';
            total_orig_price += cart_items[i].quantity * cart_items[i].price;
            if (cart_items[i].promo_amount)
                total_promo_amount +=
                    cart_items[i].quantity * cart_items[i].promo_amount;
            cart_items[i].periods = periods;
        }
        $('.accommodation-booked-list').html(html);

        if (
            typeof promo_total != 'undefined'
            && total_promo_amount > 0
        ) {
            if (total_promo_amount > promo_total) {
                total_promo_amount = promo_total;
            }
            $('.total-block .value.orig').html(ohbeFormatPrice(total_orig_price));
            $('.total-block .value.no-orig').html(
                ohbeFormatPrice(total_orig_price - total_promo_amount)
            );
        }
        else {
            $('.total-block .value.orig').html('');
            $('.total-block .value.no-orig').html(ohbeFormatPrice(total_orig_price));
        }

        if (cart_items.length > 0) {
            $('#booking-summary').show();
        }
        else {
            $('#booking-summary').hide();
        }
    }

    /**
     * Scroll to cart.
     *
     * @return void
     */
    function scrollToCart() {
        $('html, body').stop().animate({
            scrollTop: $('#booking-summary').offset().top
        }, 500);
    }

})(jQuery);

/**
 * Get occupancy icons.
 *
 * @return string Occupancy icons' html structure.
 */
function getOccupancyIcons(rate) {
    var html = '';

    if (typeof rate.adults != 'undefined' && rate.adults) {
        if (rate.adults > 5) {
            html += '<div class="dashicons dashicons-admin-users" '
                + 'title="' + trans_strings.adults + '"></div>×'+ rate.adults;
        }
        else {
            for (var j=0; j<rate.adults; j++) {
                html += '<div class="dashicons dashicons-admin-users" '
                    + 'title="' + trans_strings.adults + '"></div>';
            }
        }
    }
    if (
        (typeof rate.adults != 'undefined' && rate.adults)
        && (typeof rate.children != 'undefined' && rate.children)
        && (rate.adults > 5 || rate.children > 5)
    ) {
        html += ' + ';
    }
    if (typeof rate.children != 'undefined' && rate.children) {
        if (rate.children > 5) {
            html += '<div class="dashicons dashicons-universal-access" '
                + 'title="' + trans_strings.children + '"></div>×' + rate.children;
        }
        else {
            for (var h=0; h<rate.children; h++) {
                html += '<div class="dashicons dashicons-universal-access" '
                    + 'title="' + trans_strings.children + '"></div>';
            }
        }
    }

    return html;
}

/**
 * Render the accommodation occupancy.
 *
 * @param {string} Type of icon.
 * @param {array} Rate.
 * @return string Translated taxes information.
 */
function renderOccupancy(type, inventory_rate) {
    var icon_type = type == 'adults' ? 'admin-users' : 'universal-access';
    var name = type == 'adults' ? trans_strings.adults : trans_strings.children;
    var icon = '<div class="dashicons dashicons-' + icon_type + '"' +
        'title="' + name + '">' + '</div>';

    return inventory_rate[type] > 5
        ? icon + '×' + inventory_rate[type]
        : icon.repeat(inventory_rate[type]);
}

/**
 * Display taxes information.
 *
 * @return string Translated taxes information.
 */
function getTaxesString(cart_item, trans_strings) {
    return cart_item.excl_taxes > 0
        ? trans_strings.excl_taxes.replace('%s%', cart_item.excl_taxes)
        : trans_strings.incl_taxes;
}
