(function($) {
    'use strict';

    var first_date = new Date();
    var last_date;
    var ohbe_check_in = $('.ohbe-check-in');
    var ohbe_check_out = $('.ohbe-check-out');
    var ohbe_arrival = $('.ohbe-arrival');

    if (typeof calendar_data != 'undefined' && calendar_data) {
        first_date = ohbeGetDateFromIso(calendar_data.first_date);
        last_date = ohbeGetDateFromIso(calendar_data.last_date);
    }

    ohbe_check_in.datepicker({
        monthNames: dp_args.monthNames,
        monthNamesShort: dp_args.monthNamesShort,
        dayNames: dp_args.dayNames,
        dayNamesShort: dp_args.dayNamesShort,
        dayNamesMin: dp_args.dayNamesMin,
        firstDay: dp_args.firstDay,
        isRTL: dp_args.isRTL,
        dateFormat: 'dd-mm-yy',
        minDate: $.datepicker.formatDate('dd-mm-yy', first_date),
        maxDate: $.datepicker.formatDate('dd-mm-yy', last_date),
        beforeShowDay: ohbeMayCheckIn,
        onSelect: ohbeOnSelectCheckInDate
    });

    ohbe_check_out.datepicker({
        dateFormat: 'dd-mm-yy',
        monthNames: dp_args.monthNames,
        monthNamesShort: dp_args.monthNamesShort,
        dayNames: dp_args.dayNames,
        dayNamesShort: dp_args.dayNamesShort,
        dayNamesMin: dp_args.dayNamesMin,
        firstDay: dp_args.firstDay,
        isRTL: dp_args.isRTL,
        onSelect: ohbeOnSelectCheckOutDate
    });

    if (search_filters.promotion_code != '') {
        $('.ohbe-promo').val(search_filters.promotion_code);
    }
    if (search_filters.arrival) {
        ohbe_check_in.datepicker('setDate', search_filters.arrival);
    }
    if (search_filters.departure) {
        ohbe_check_out.datepicker('setDate', search_filters.departure);
    }

    ohbeSetCheckOutAvailableRange(ohbe_check_in, ohbe_check_out);
    ohbeSetNights(ohbe_check_in, ohbe_check_out);

    ohbe_arrival.datepicker({
        monthNames: dp_args.monthNames,
        monthNamesShort: dp_args.monthNamesShort,
        dayNames: dp_args.dayNames,
        dayNamesShort: dp_args.dayNamesShort,
        dayNamesMin: dp_args.dayNamesMin,
        firstDay: dp_args.firstDay,
        isRTL: dp_args.isRTL,
        dateFormat: 'dd-mm-yy',
        minDate: $.datepicker.formatDate('dd-mm-yy', new Date())
    });

    /**
     * Add days to a given date.
     *
     * @param {object} d Date object.
     * @param {int} numdays Number of days to add.
     * @returns {object} The date that is numdays after d.
     */
    function ohbeDateAdd(d, numdays) {
        return moment(d).add(numdays, 'days').toDate();
    }

    /**
     * Get the number of days between the first date and the given date.
     *
     * @param {string} date Date string with GMT format.
     * @returns {int} Number of days.
     */
    function ohbeGetCalendarDataIndex(date) {
        var d = moment(date);
        var fd = moment(first_date);
        return d.diff(fd, 'days');
    }

    /**
     * Return a Date object for the given YYYY-MM-DD string.
     *
     * @param {string} s Date string.
     * @returns {object}
     */
    function ohbeGetDateFromIso(s) {
        return moment(s, "YYYY-MM-DD").toDate();
    }

    /**
     * Return whether check in date is available or not.
     *
     * @param {string} date Date string with GMT format.
     * @returns {array} Array with boolean value for enable/disable date button.
     * There are three cases:
     *  1. TRUE: Date is available in Calendar Data.
     *  2. FALSE: Date is unavailable in Calendar Data.
     *  3. TRUE: Calendar Data hasn't been defined.
     */
    function ohbeMayCheckIn(date) {
        if (typeof calendar_data != 'undefined' && calendar_data) {
            var index = ohbeGetCalendarDataIndex(date);
            return [calendar_data.dates_info[index] == '1']; // 1, 2
        }

        return [true]; // 3
    }

    /**
     * Trigger when a check in date is selected in the availability search form.
     *
     * @returns {void}
     */
    function ohbeOnSelectCheckInDate() {
        var check_out_input = $(this).siblings('.ohbe-check-out');
        ohbeSetCheckOutAvailableRange($(this), check_out_input);
        check_out_input.datepicker(
            'setDate',
            ohbeDateAdd($(this).datepicker('getDate'), 1)
        );
        ohbeSetNights($(this), check_out_input);
    }

    /**
     * Trigger when a check out date is selected in the availability search form.
     *
     * @returns {void}
     */
    function ohbeOnSelectCheckOutDate() {
        ohbeSetNights($(this).siblings('.ohbe-check-in'), $(this));
    }

    /**
     * Set the available range of departure date.
     *
     * @param {object} check_in_input Check in input to be set.
     * @param {object} check_out_input Check out input to be set.
     * @returns {void}
     */
    function ohbeSetCheckOutAvailableRange(check_in_input, check_out_input) {
        if (typeof calendar_data != 'undefined' && calendar_data) {
            var check_in_date = check_in_input.datepicker('getDate');
            check_out_input.datepicker(
                'option',
                'minDate',
                $.datepicker.formatDate(
                    'dd-mm-yy',
                    ohbeDateAdd(check_in_date || first_date, 1)
                )
            );
            // Searching of available range starts at min date index, so a check out
            // date can be set when this is not available for check in
            var min_date_index = ohbeGetCalendarDataIndex(
                check_in_date ? check_in_date : first_date
            );

            var max_date_index = calendar_data.dates_info.length;
            for (var i=min_date_index; i<max_date_index; i++) {
                if (calendar_data.dates_info[i] == '-') {
                    max_date_index = i;
                    break;
                }
            }

            check_out_input.datepicker(
                'option',
                'maxDate',
                $.datepicker.formatDate(
                    'dd-mm-yy',
                    ohbeDateAdd(
                        check_in_date || first_date,
                        max_date_index - min_date_index
                    )
                )
            );
        }
    }

    /**
     * Calculate the nights between two dates.
     *
     * @param {string} check_in_input Checkin input date.
     * @param {string} check_out_input Checkout input date.
     * @returns {void}
     */
    function ohbeSetNights(check_in_input, check_out_input) {
        var to = moment(check_out_input.datepicker('getDate'));
        var from = moment(check_in_input.datepicker('getDate'));
        var nights = to.diff(from, 'days');
        if (nights < 1) {
            nights = 1;
        }
        $('.ohbe-nights-number').html(nights);
        $('.ohbe-nights-name').html(translation.nights + ':');
    }

    $('.ohbe-modal .close, .ohbe-modal .accept, .more').on('click', ohbeModalClose);

    $(document).keyup(function(e){
        if (e.which == 27) {
            ohbeModalClose();
        }
    });
})(jQuery);


/**
 * Get formatted price depending on inventory currency data.
 *
 * @return string Formatted price.
 */
function ohbeFormatPrice(price) {
    var formatted_price = parseFloat(price).toFixed(inv_currency.digits);

    if (inv_currency.before) {
        return inv_currency.symbol + ' ' + formatted_price;
    }

    return formatted_price + ' ' + inv_currency.symbol;
}

/**
 * Get the carousel html.
 *
 * @param {string} id Accommodation id.
 * @param {string} active_id Active accommodation id.
 * @return string Carousel's html structure.
 */
function ohbeRenderCarousel(id, active_id) {
    var carousel_id = 'modal-carousel';
    var images_ids = inv_accos[id]['images'];
    var html = '<div id=' + carousel_id + ' class="carousel slide"'
        + ' data-ride=carousel><ol class=carousel-indicators>';
    for (var i = 0; i < images_ids.length; i++) {
        html += '<li data-target=#' + carousel_id + ' data-slide-to=' + i;
        if (images_ids[i] === active_id) {
            html += ' class=active';
        }
        html += '></li>';
    }
    html += '</ol>'
     + '<div class=carousel-inner role=listbox>';
    for (var i = 0; i < images_ids.length; i++) {
        html += '<div class="item'
        if (images_ids[i] === active_id) {
            html += ' active'
        }
        html += '"><img src=' + inv_images[images_ids[i]]['url'] + '></div>';
    }
    html += '</div><a class="left carousel-control" href=#' + carousel_id
        + ' role=button data-slide=prev><span '
        + 'class="glyphicon glyphicon-chevron-left" aria-hidden=true></span>'
        + '<span class=sr-only>Previous</span></a>'
        + '<a class="right carousel-control" href=#' + carousel_id
        + ' role=button data-slide=next><span'
        + ' class="glyphicon glyphicon-chevron-right" aria-hidden=true></span>'
        + '<span class=sr-only>Next</span></a></div>';

    html += '</div>'
        + '<a '
            + 'class="left carousel-control" '
            + 'data-slide=prev '
            + 'href=#' + carousel_id + ' '
            + 'role=button>'
        + '<span '
            + 'aria-hidden=true '
            + 'class="glyphicon glyphicon-chevron-left">'
        + '</span>'
        + '<span class=sr-only>Previous</span>'
        + '</a>'
        + '<a '
            + 'class="right carousel-control" '
            + 'href=#' + carousel_id + ' '
            + 'role=button data-slide=next>'
        + '<span '
            + 'aria-hidden=true '
            + 'class="glyphicon glyphicon-chevron-right>"'
        + '</span>'
        + '<span class=sr-only>Next</span>'
        + '</a>'
        + '</div>';

    return html;
}

/**
 * Get image.
 *
 * @return string Image's html structure.
 */
function ohbeRenderImage(id, type) {
    if (type == 'item') {
        var inv_type = inv_items;
    } else {
        var inv_type = inv_accos;
    }

    if (
        typeof inv_type[id] != 'undefined'
        && inv_type[id].images[0] != null
        && typeof inv_images[inv_type[id].images[0]].url != 'undefined'
    ) {
        return '<div class=ohbe-image>'
            + '<img src=' + inv_images[inv_type[id].images[0]].url + '>'
            + '</div>';
    }

    return '';
}

function ohbeGetName(translations, base, id) {
    return (typeof translations[id].name == 'undefined')
        ? base[id].name
        : translations[id].name;
}

/*
 * Open a given modal.
 */
function ohbeModalOpen(modal) {
    modal.detach().appendTo('body');
    jQuery('html, body').addClass('with-overlay');
    modal.show();
}

/*
 * Close any opened modal.
 */
function ohbeModalClose() {
    jQuery('.ohbe-modal').hide();
    jQuery('html, body').removeClass('with-overlay');
}
