(function($) {
    'use strict';
    var reservation_submit = $('#reservation-submit');
    var submitted = false;

    $('input[name="ohbe_card_number"]').on('propertychange input', function () {
        if ($(this).val().length < 19) {
            $(this).val(ccFormat($(this).val()));
        }
    }).on('keypress', function(ev) {
        // Only allow numbers, Return, Esc and Supr keys. When max characters,
        // Only allow Esc and Supr keys.
        // Key 0: Delete
        // Key 8: Backspace
        // Keys between 48 & 57: Numbers
        if (
            ev.which != 0
            && ev.which != 8
            && (ev.which < 48 || ev.which > 57 || $(this).val().length > 20)
        ) {
            return false;
        }
    });

    $('.modal-button').on('click', function() {
        var data_modal = $(this).data('modal');
        ohbeModalOpen($('#ohbe-' + data_modal));
    });

    $('#ohbe-reservation-form').find($(':input[required]')).on('focusout', function() {
        if ($(this).val() != '') {
            $(this).removeClass('error-border');
        } else {
            $(this).addClass('error-border');
        }
    });

    reservation_submit.on('click', function() {
        var fields = $('#ohbe-reservation-form').find($(':input[required]'));
        var required = [];
        var form_errors = 0;

        for (var i = 0 ; i < fields.length; i++) {
            if (
                fields[i].value == ''
                || (
                    fields[i].type == 'checkbox'
                    && fields[i].checked == false
                )
            ) {
                required.push(fields[i]);
            }
        }

        if (required.length > 0) {
            form_errors++;
            for (i = 0; i < required.length; i++) {
                required[i].classList.add('error-border');
            }
            required[0].scrollIntoView();
            required[0].focus();
            alert(ohbe_field_errors.empty_fields);
        }

        if (!checkOccupation()) {
            form_errors++;
            alert(ohbe_field_errors.occupation_exceed);
        }

        if (form_errors < 1 && !submitted) {
            submitted = true;
            $('#ohbe-reservation-form').submit();
        } else {
            return;
        }
    });

    $('.people-number').on('change', checkOccupation);

    function checkOccupation() {
        var ch_select = $("select[name^='ohbe_children']").eq(0);
        var ad_select = $("select[name^='ohbe_adult']").eq(0);
        var p_max = ch_select.parent().data('max');
        if (parseInt(ad_select.val()) + parseInt(ch_select.val()) > p_max) {
            ch_select.addClass('error-border');
            ad_select.addClass('error-border');
            return false;
        }
        ch_select.removeClass('error-border');
        ad_select.removeClass('error-border');
        return true;
    }

})(jQuery);

/**
 * Format credit card number. Add a space every
 * 4 digits, except last block of 6 digits.
 * Max. digits allowed: 18.
 *
 * @return string Credit card's digits.
 */
function ccFormat(value) {
    var v = value.replace(/\s+/g, '').replace(/[^0-9]/gi, '');
    var matches = v.match(/\d{4,18}/g);
    var match = matches && matches[0] || '';
    var parts = [];

    for (var i=0; i<match.length; i+=4) {
        parts.push(match.substring(i, i + 4));
    }
    if (parts.length) {
        return parts.join(' ');
    }

    return value;
}
