<?php
defined('ABSPATH') or exit();

/**
 * Handles parameters POST & GET params when
 * search form has been submitted.
 *
 * @return void
 */
function ohbeSearchForm () {
    if (
        $_SERVER['REQUEST_METHOD'] == "POST"
        && isset($_POST['ohbe_search_submit'])
    ) {
        if (isset($_POST['acco_id'])) {
            $id = $_POST['acco_id'];
        }
        elseif (isset($_GET['acco'])) {
            $id = $_GET['acco_id'];
        }
        else {
            $id = false;
        }
        $errors = ohbeSearchFormHandle($id);
    }
}

add_action('init', 'ohbeSearchForm');

/**
 * Create search form.
 *
 * @param null $atts
 * @param bool $is_widget
 *
 * @return string Search form's html structure.
 */
function ohbeSearchFormOutput ($atts=null, $is_widget=false) {
    ohbeSetCalendarData();
    $a = shortcode_atts(
        array(
            'acco_id' => null,
            'promo_field' => null
        ),
        $atts
    );
    $id = null;
    if (isset($_GET['acco'])) {
        $id = $_GET['acco'];
    }
    if (!$is_widget && !is_page(get_option(''))) {
        ob_start();
    }
    $html = '<form class=ohbe-search-form method=POST>'
         . '<div class=form-group><div class=input-group>';
    $html .= sprintf(
        '<input name=ohbe_arrival class=ohbe-check-in '
        . 'placeholder="%s" required readonly>',
        __('Arrival', 'ohbe')
    );
    $html .= sprintf(
        '<input name=ohbe_departure class=ohbe-check-out '
        . 'placeholder="%s" required readonly>',
        __('Departure', 'ohbe')
    );
    if (isset($_GET['pr']) || isset($atts['ispr'])) {
        $html .= sprintf(
            '<input name=ohbe_promo class=ohbe-promo placeholder="%s">',
            __( 'Promo code', 'ohbe' )
        );
        $html.= '<input type=hidden name=ispr value="1">';
    }
    if (isset($a['acco_id'])) {
        $html .= sprintf(
            '<input type=hidden name=acco_id value="%s">',
            intval($a['acco_id'])
        );
    }
    $html .= sprintf(
        '<button type=submit name=ohbe_search_submit '
        . 'class="btn-ohbe ohbe-search-submit">%s</button></div>',
        __('Search', 'ohbe')
    );
    if (isset($_GET['ohbe'])) {
        $html .= sprintf('<div class=nights>'
            . '<span class=ohbe-nights-name></span> '
            . '<span class=ohbe-nights-number></span> '
            . '</div>'
        );
    }
    $html .= '</div></form>';
    printf($html);

    global $errors_ohbe;
    if (is_wp_error($errors_ohbe) && $errors_ohbe->get_error_messages() > 0) {
        printf(
            '<div class="alert alert-danger">%s</div>',
            $errors_ohbe->get_error_message()
        );
    }
    if (!$is_widget) {
        $output = ob_get_clean();
        return $output;
    }
}

add_shortcode('ohbe_main_search', 'ohbeSearchFormOutput');

/**
 * Handles search form for shortcode
 *
 * @param array $atts Shortcode attributes.
 *
 * @return string Search form's html structure.
 */
function ohbeSearchShortcode($atts) {
    ohbeSetCalendarData();
    $a = shortcode_atts(array(
        'acco_id' => null,
        'promo_field' => false
    ), $atts);
    $accommodation = '';
    $ispr = '';

    if ($a['acco_id']) {
        $sanitized = intval($a['acco_id']);
        $accommodation = sprintf('<input type=hidden name=acco_id value="%s">',
            $sanitized
        );
    }
    if ($a['promo_field']) {
        $ispr = '<input type=hidden name=ispr value=1>';
    }
    $html = '<form class=ohbe-search-form method=POST>'
        . '<div class=form-group><div class=input-group>';
    $html .= sprintf(
        '<input name=ohbe_arrival class=ohbe-check-in '
        . 'placeholder="%s" required readonly>',
        __('Arrival', 'ohbe')
    );
    $html .= sprintf(
        '<input name=ohbe_departure class=ohbe-check-out '
        . 'placeholder="%s" required readonly>',
        __('Departure', 'ohbe')
    );
    if ($a['promo_field']) {
        $html .= sprintf(
            '<input name=ohbe_promo class=ohbe-promo placeholder="%s">',
            __( 'Promo code', 'ohbe' ),
            $ispr
        );
    }
    $html .= sprintf(
        '<input type=hidden name=ohbe_check_in_value>'
        . '<input type=hidden name="ohbe_check_out_value">%s',
        $accommodation
    );
    $html .= sprintf(
        '<button type=submit name=ohbe_search_submit '
        . 'class="btn-ohbe ohbe-search-submit">'
        .'%s</button></div></div></form>',
        __('Search', 'ohbe')
    );

    return $html;
}

add_shortcode('ohbe_search', 'ohbeSearchShortcode');

/**
 * Set calendar data just once, depending on whether
 * a search form (shortcode/widget) is been displayed
 *
 * @return void
 */
function ohbeSetCalendarData() {
    if (!OHBE_Main::getIsSearchFormDisplayed() && !is_admin()) {
        wp_localize_script(
            'ohbe_common',
            'calendar_data',
            OscarAPI::getCalendarData()
        );
        OHBE_Main::setIsSearchFormDisplayed(true);
    }
}
