<?php
defined('ABSPATH') or exit();

/**
 * Handles parameters POST & GET params when
 * search form has been submitted.
 *
 * @return void
 */
function ohbeShowForm () {
    if ($_SERVER['REQUEST_METHOD'] == "POST" && isset($_POST['ohbe_show_submit'])) {
        $arrival_date = DateTime::createFromFormat(
            '!d-m-Y',
            $_POST['ohbe_check_in']
        );
        OHBE_Reservation::setReservationParam('arrival', $arrival_date);
        OHBE_Reservation::setReservationParam(
            'reserv_id',
            $_POST['ohbe_reserv_id']
        );
        OHBE_Reservation::setReservationParam('name', $_POST['ohbe_name']);
        $url_params = OHBE_Tools::setUrlParams(OHBE_REVIEW_PAGE);
        $url = esc_url_raw(add_query_arg($url_params, OHBE_Tools::getBaseUrl()));
        wp_safe_redirect($url);
        exit;
    }
}

add_action('init', 'ohbeShowForm');

/**
 * Create show form.
 *
 * @param null $atts
 * @param bool $is_widget
 *
 * @return string Search form's html structure.
 */
function ohbeShowFormOutput ($atts=null, $is_widget=false) {
    if (!$is_widget && !is_page(get_option(''))) {
        ob_start();
    }
    echo ohbeShowShortcode();

    global $errors_ohbe;
    if (is_wp_error($errors_ohbe) && $errors_ohbe->get_error_messages() > 0) {
        printf(
            '<div class="alert alert-danger">%s</div>',
            $errors_ohbe->get_error_message()
        );
    }
    if (!$is_widget) {
        $output = ob_get_clean();
        return $output;
    }
}

add_shortcode('ohbe_main_show', 'ohbeShowFormOutput');

/**
 * Handles show form for shortcode
 *
 * @return string Search form's html structure.
 */
function ohbeShowShortcode() {
    return '<form class=ohbe-show-form method=POST>'
        . '<div class=form-group><div class=input-group>'
        . '<input name=ohbe_reserv_id class=ohbe-reservation-number '
        . 'placeholder="' . __('Reservation number', 'ohbe') . '" required>'
        . '<input name=ohbe_check_in class=ohbe-arrival '
        . 'placeholder="' . __('Arrival', 'ohbe') . '" required readonly>'
        . '<input name=ohbe_name class=ohbe-name '
        . 'placeholder="' . __('Full name', 'ohbe') . '" required>'
        . '<button type=submit name=ohbe_show_submit '
        . 'class="btn-ohbe ohbe-show-submit">' . __('Search', 'ohbe')
        . '</button></div></div></form>';
}

add_shortcode('ohbe_show', 'ohbeShowShortcode');
